summaryrefslogtreecommitdiffstats
path: root/donation-calc
diff options
context:
space:
mode:
authorDrew DeVault <ddevault@vistarmedia.com>2018-01-18 15:37:20 -0500
committerDrew DeVault <ddevault@vistarmedia.com>2018-01-18 15:37:20 -0500
commitff1be21d56998f48317bda335080d21b2fc2aa13 (patch)
treef9896c2f7d2f60a66dca5abf2efd4db654bd5c84 /donation-calc
parentcb3c43db8053285cef475ecc64efce506b4d9052 (diff)
Fix typos in donation calc
Diffstat (limited to 'donation-calc')
-rw-r--r--donation-calc/index.js10
1 files changed, 5 insertions, 5 deletions
diff --git a/donation-calc/index.js b/donation-calc/index.js
index 7d6aee2..08faee2 100644
--- a/donation-calc/index.js
+++ b/donation-calc/index.js
@@ -256,7 +256,7 @@ class Calculator extends Component {
creator.toFixed(2)}</strong> per {
frequency} for <strong>{duration} {frequency}(s)</strong>.
If they wait until the end of this timeframe to withdraw their funds,
- their <strong>withdrawl fees</strong> will look like this:
+ their <strong>withdrawal fees</strong> will look like this:
</p>
<fieldset class="form-group" style={{ marginTop: "1rem" }}>
<label class="radio-inline">
@@ -300,7 +300,7 @@ class Calculator extends Component {
</thead>
<tbody>
<tr>
- <td>Withdrawl fee</td>
+ <td>Withdrawal fee</td>
<td></td>
<td
style={{ textAlign: "right" }}
@@ -491,7 +491,7 @@ class Calculator extends Component {
<td></td>
</tr>,
<tr>
- <td>Withdrawl fee*</td>
+ <td>Withdrawal fee*</td>
<td>1% (25ยข min, $20 max)</td>
<td
style={{ textAlign: "right" }}
@@ -519,10 +519,10 @@ class Calculator extends Component {
</tbody>
</table>
<small>
* Withdrawl fee assumes payout via PayPal. Numbers for payout via
Stripe are not available, and numbers for Payoneer are different. <a
href="https://patreon.zendesk.com/hc/en-us/articles/203913489-What-are-my-options-to-receive-payout-">Details here</a>.
- Withdrawl fees are also applied on the total sum of the creator's
+ Withdrawal fees are also applied on the total sum of the creator's
earnings, and capped at $20 across all earnings.
</small>
</div>
@@ -519,10 +519,10 @@ class Calculator extends Component {
</table>
<small>
- * Withdrawl fee assumes payout via PayPal. Numbers for payout via
+ * Withdrawal fee assumes payout via PayPal. Numbers for payout via
Stripe are not available, and numbers for Payoneer are different. <a
href="https://patreon.zendesk.com/hc/en-us/articles/203913489-What-are-my-options-to-receive-payout-">Details here</a>.